@@ -17,7 +17,7 @@ require Exporter;
 
 @ISA       = qw(Exporter);
 @EXPORT_OK = qw(encrypt decrypt encrypt_hex decrypt_hex);
-$VERSION   = '2.10';
+$VERSION   = '2.15';
 
 
 ########################################
@@ -80,11 +80,29 @@ sub new ($;$$$)
 #
 # set attributes if argument given, return attribute value
 #
-sub module	(\$)	{                                              return $_[0]->{module}    }
-sub keysize	(\$;$)	{ $_[0]->{keysize}   = $_[1] if defined $_[1]; return $_[0]->{keysize}   }
-sub blocksize	(\$;$)	{ $_[0]->{blocksize} = $_[1] if defined $_[1]; return $_[0]->{blocksize} }
-sub key		(\$;$)	{ $_[0]->{key}       = $_[1] if defined $_[1]; return $_[0]->{key}       }
-sub mode	(\$)	{                                              return $_[0]->{mode}      }
+sub module	(\$)	{                                      return $_[0]->{module}    }
+sub keysize	(\$;$)	{ $_[0]->{keysize}   = $_[1] if $_[1]; return $_[0]->{keysize}   }
+sub blocksize	(\$;$)	{ $_[0]->{blocksize} = $_[1] if $_[1]; return $_[0]->{blocksize} }
+sub mode	(\$)	{                                      return $_[0]->{mode}      }
+
+#
+# sets key if argument given
+#
+sub key (\$;$)
+{
+	my $self = shift;
+
+	if (my $key = shift)
+	{
+		$self->{key} = $key;
+
+		# forget cipher object to force creating a new one
+		# otherwise a key change would not be recognized
+		$self->{_cipherobj} = '';
+	}
+
+	return $self->{key};
+}
 
 #
 # sets padding method if argument given
@@ -156,7 +174,7 @@ sub cipher (\$;$)
 
 			# delete possibly existing cipher obj from a previous crypt process
 			# otherwise changes in the cipher would not be recognized by start()
-			delete $self->{_cipherobj};
+			$self->{_cipherobj} = '';
 		}
 
 		# some packages like Crypt::DES and Crypt::IDEA behave strange in the way
@@ -276,8 +294,8 @@ sub finish (\$)
 		unless $mode;
 
 	# cleanup: forget mode, purge buffer
-	$self->{mode}    = '';
-	$self->{_buffer} = '';
+	$self->{mode}		= '';
+	$self->{_buffer}	= '';
 
 	return '' unless defined $data;
 
@@ -494,8 +512,7 @@ preferred. See textbooks on cryptography if you want to know why.
 The functionality of the module can be accessed via OO methods or via
 standard function calls. Remember that some block cipher module like for
 example Crypt::Blowfish has to be installed. The syntax of Crypt::ECB
-follows that of Crypt::CBC, so it can more or less be used as a drop-in
-replacement.
+follows that of Crypt::CBC.
 
 =head1 METHODS
 
